import VueDatePicker from '@vuepic/vue-datepicker'
import { createApp, defineAsyncComponent, h } from 'vue'
import Vue3Toasity, { type ToastContainerOptions } from 'vue3-toastify'

import App from '@/app/App.vue'

import { PageLayout } from '@/widgets'
import {
    AuthCard,
    AuthForm,
    Button,
    ButtonMenu,
    Card,
    FileCard,
    IconBase,
    type IconNames,
    InfinityLoading,
    Input,
    Link,
    Logo,
    Spinner,
    Tabs,
    Tag,
    ToastIcon,
    Tooltip,
    TransitionFade,
    UserBase,
    Dropdown,
    Textarea,
} from '@/shared'

export const create = () => {
    const app = createApp(App)

    app.use(Vue3Toasity, {
        autoClose: 2000,
        hideProgressBar: true,
        pauseOnHover: false,
        icon: ({ type }) =>
            h(ToastIcon, {
                view: type,
            }),
        closeButton: ({ closeToast }) =>
            h(IconBase, {
                name: 'close' as IconNames,
                class: 'Toastify__close-button',
                onClick: closeToast,
            }),
    } as ToastContainerOptions)

    app.component('VueDatePicker', VueDatePicker)
    app.component('icon-base-component', IconBase)
    app.component('button-component', Button)
    app.component('card-component', Card)
    app.component('file-card-component', FileCard)
    app.component('transition-fade-component', TransitionFade)
    app.component('input-component', Input)
    app.component('page-layout-component', PageLayout)
    app.component('user-base-component', UserBase)
    app.component('link-component', Link)
    app.component('button-menu-component', ButtonMenu)
    app.component('tag-component', Tag)
    app.component('tooltip-component', Tooltip)
    app.component('spinner-component', Spinner)
    app.component('tabs-component', Tabs)
    app.component('infinity-loading-component', InfinityLoading)
    app.component('logo-component', Logo)
    app.component('auth-form-component', AuthForm)
    app.component('auth-card-component', AuthCard)
    app.component('dropdown-component', Dropdown)
    app.component('textarea-component', Textarea)

    //modals
    app.component(
        'modal-dialog-component',
        defineAsyncComponent(
            () => import('@/widgets/modals/ui/ModalDialog/ModalDialog.vue'),
        ),
    )

    app.component(
        'modal-edit-patient-component',
        defineAsyncComponent(
            () => import('@/widgets/modals/ui/EditPatient/EditPatient.vue'),
        ),
    )

    app.component(
        'modal-select-questionnaire-component',
        defineAsyncComponent(
            () =>
                import(
                    '@/widgets/modals/ui/SelectQuestionnaires/SelectQuestionnaires.vue'
                ),
        ),
    )

    app.component(
        'modal-add-destination-component',
        defineAsyncComponent(
            () =>
                import(
                    '@/widgets/modals/ui/ModalAddDestination/ModalAddDestination.vue'
                ),
        ),
    )

    app.component(
        'modal-add-reminder-component',
        defineAsyncComponent(
            () =>
                import(
                    '@/widgets/modals/ui/ModalAddReminder/ModalAddReminder.vue'
                ),
        ),
    )

    app.component(
        'modal-view-questionnaire-component',
        defineAsyncComponent(
            () =>
                import(
                    '@/widgets/modals/ui/ModalViewQuestionnaire/ModalViewQuestionnaire.vue'
                ),
        ),
    )

    app.component(
        'modal-analysis-hint-component',
        defineAsyncComponent(
            () => import('@/widgets/modals/ui/AnalysisHints/AnalysisHints.vue'),
        ),
    )

    app.component(
        'modal-view-optimums-component',
        defineAsyncComponent(
            () => import('@/widgets/modals/ui/ViewOptimums/ViewOptimums.vue'),
        ),
    )

    return app
}
