import type { NavigationGuardNext, RouteLocationNormalized } from 'vue-router'
import { tokenValidate } from '@/features'
import { Routes } from '@/shared'

export type MiddlewareContext = {
    to: RouteLocationNormalized
    from: RouteLocationNormalized
    next: NavigationGuardNext
}

export type Middleware = (context: MiddlewareContext) => any

export const guest = async ({ next }: MiddlewareContext) => {
    const isAuth = await tokenValidate()

    if (isAuth) {
        return next({
            name: Routes.INDEX,
        })
    }

    return next()
}

export const auth = async ({ next }: MiddlewareContext) => {
    const isAuth = await tokenValidate()

    if (!isAuth) {
        return next({
            name: Routes.LOGIN,
        })
    }

    return next()
}

export const patient = ({ to, next }: MiddlewareContext) => {
    if (to.params.id) {
        return next()
    }

    return next({ name: Routes.MY_PATIENTS })
}
