import type { RouteRecordRaw } from 'vue-router'
import { Routes } from '@/shared'
import { auth, guest, patient } from './middlewares'

export const routes: RouteRecordRaw[] = [
    {
        path: '/',
        name: Routes.INDEX,
        redirect: { name: Routes.MY_PATIENTS },
        meta: {
            middleware: [auth],
        },
    },
    {
        path: '/patient/:id?',
        name: Routes.PATIENT,
        props: true,
        component: () => import('@/pages/patient/ui/Patient/Patient.vue'),
        meta: {
            middleware: [auth, patient],
            page: {
                title: 'Пациента',
            },
        },
    },
    {
        path: '/my-patients',
        name: Routes.MY_PATIENTS,
        component: () =>
            import('@/pages/patients/ui/MyPatients/MyPatients.vue'),
        meta: {
            middleware: [auth],
            page: {
                title: 'Мои пациенты',
            },
        },
    },
    {
        path: '/requests-patients',
        name: Routes.REQUESTS_PATIENTS,
        component: () =>
            import('@/pages/patients/ui/RequestsPatients/RequestsPatients.vue'),
        meta: {
            middleware: [auth],
            page: {
                title: 'Запросы на ведение',
            },
        },
    },
    {
        path: '/calendar',
        name: Routes.CALENDAR,
        component: () => import('@/pages/calendar/ui/Calendar/Calendar.vue'),
        meta: {
            middleware: [auth],
            page: {
                title: 'Календарь',
            },
        },
    },
    {
        path: '/chat',
        name: Routes.CHAT,
        component: () => import('@/pages/chat/ui/Chat/Chat.vue'),
        meta: {
            middleware: [auth],
            page: {
                title: 'Чат',
            },
        },
    },
    {
        path: '/videochat',
        name: Routes.VIDEOCHAT,
        component: () => import('@/pages/videochat/ui/Videochat/Videochat.vue'),
        meta: {
            middleware: [auth],
            page: {
                title: 'Видеочат',
            },
        },
    },
    {
        path: '/library',
        name: Routes.LIBRARY,
        component: () => import('@/pages/library/ui/Library/Library.vue'),
        meta: {
            middleware: [auth],
            page: {
                title: 'Моя библиотека',
            },
        },
    },
    {
        path: '/login',
        name: Routes.LOGIN,
        component: () => import('@/pages/login/ui/LoginPage/LoginPage.vue'),
        meta: {
            middleware: [guest],
        },
    },
    {
        path: '/support',
        name: Routes.SUPPORT,
        component: () => import('@/pages/support/ui/Support/Support.vue'),
        meta: {
            middleware: [auth],
            page: {
                title: 'Поддержка',
            },
        },
    },
    {
        path: '/profile',
        name: Routes.PROFILE,
        component: () => import('@/pages/profile/ui/Profile/Profile.vue'),
        meta: {
            middleware: [auth],
            page: {
                title: 'Профиль',
            },
        },
    },
    {
        path: '/login/yandex/processing',
        name: Routes.YANDEX_PROCESSING,
        component: () => import('@/pages/callback/ui/CallBack/AuthCallBack.vue'),
        meta: {
            middleware: [guest]
        },
    }
]
