import type { Appointments, Patient, PatientAnalysis } from '@/entities'

export type Medical = {
    survey_list: MedicalSurvey[]
    treatment_courses: TreatmentCourse[]
    patient_treatment: TreatmentCourse[]
    survey: Maybe<SurveyDetail>
    medical_test: MedicalTest[]
}

export type MedicalSurvey = {
    id: number
    title: string
    description: string
    questions_count: number | string
}

export type SetSurveyData = {
    customer_id: number
    survey_ids: number[]
}

export type AddReminderData = {
    performer_id: number // user id
    datetime: string
    type: 'appointment' | 'notice'
    text: string
}

export type TreatmentCourse = {
    id: number
    title: string
    duration: number
    created_at: string | null
    updated_at: string | null
    nutrition: string | null
    medication: string | null
    buds: string | null
    analysis_and_research: string | null
    comment: string | null
    enable: 1 | 0
}

export type SurveyDetail = {
    id: number
    title: string
    description: string
    questions: {
        id: number
        question_text: string
        question_type: 'text' | 'checkbox' | 'radio'
        survey_id: number
        options: {
            id: number
            option: string
            question_id: number
            sort: null
            is_selected?: boolean
            model?: any
        }[]
        answers?: {
            id: number
            question_id: number
            survey_attempt_id: number
            user_id: number
            answer_text: string
            question_option_id: number | null
        }[]
    }[]
}

export type MedicalTest = {
    id: number
    title: string
    created_at: null | string
    updated_at: null | string
    unit: null | string
    markers: {
        id: number
        name: string
        list_medical_test_id: number
        unit: null | string
        created_at: null | string
        updated_at: null | string
        tip_min: null | string
        tip_max: null | string
        notice: null | string
        optimums: MarkerOptimums[]
        optimums_custom: MarkerOptimums[]
        head: string[]
        result: any[]
    }[]
}

// For displaying analysis
export type TestMarkers = {
    id: number
    name: string
    list_medical_test_id: number
    unit: null | string
    created_at: null | string
    updated_at: null | string
    tip_min: null | string
    tip_max: null | string
    notice: null | string
    optimums: MarkerOptimums | MarkerOptimums[]
    optimums_custom: any[]
    result?: PatientAnalysis[]
}

export type MarkerOptimums = {
    id: number
    marker_id: number
    sex: string
    age: string
    min: number
    max: number
    created_at: string
    updated_at: string
    interval?: string
}

export type BaseAnalysisOptimumValues = {
    type: 'base' | 'custom'
    test_id: MedicalTest['id']
    sex: string
    value: string
}

export type AddTreatmentCourseData = {
    user_id: number
    appointment_id: number
    treatment_course_id?: number
    enabled?: boolean | number
    file?: File
}

export type DeleteAppointmentData = {
    appointment: Appointments['id']
}

export type DeleteTreatmentCourseFromPatientData = {
    user_id: Patient['id']
    treatment_course_id: TreatmentCourse['id']
}

export type ViewSurveyAnswersData = {
    customer_id: Patient['id']
    survey_attemp_id: MedicalSurvey['id']
}

export type AddOrUpdateOptimumData = {
    list_medical_test_id: number
    marker_id: number
    sex: string
    age: string
    min: number
    max?: number
}

export type AddOrUpdateAnalysisData = {
    list_medical_test_id: number
    result?: number | null
    quality: string
    date: string
    user_id: number
    marker_id: number
}

export type HealthMatrixData = {
    appointment_id: number
    antecedents?: string | null
    triggers?: string | null
    medmators?: string | null
    nutrition?: string | null
    sleep?: string | null
    movement?: string | null
    stress?: string | null
    relation?: string | null
    assimilation?: string | null
    assimilation_color?: string | null
    energy?: string | null
    energy_color?: string | null
    inflammation?: string | null
    inflammation_color?: string | null
    structure?: string | null
    structure_color?: string | null
    mental?: string | null
    mental_color?: string | null
    communications?: string | null
    communications_color?: string | null
    transport?: string | null
    transport_color?: string | null
    detoxification?: string | null
    detoxification_color?: string | null
    circle_mental?: string | null
    circle_spiritual?: string | null
    circle_emotional?: string | null
}

export type TreatmentCourseData = {
    user_id: Patient['id']
    treatment_course_id?: TreatmentCourse['id']
    payload?:
        | {
              nutrition?: TreatmentCourse['nutrition']
              medication?: TreatmentCourse['medication']
              buds?: TreatmentCourse['buds']
              analysis_and_research?: TreatmentCourse['analysis_and_research']
              comment?: TreatmentCourse['comment']
              title?: TreatmentCourse['title']
              enable?: TreatmentCourse['enable']
          }
        | FormData
}
