import { onBeforeUnmount, onMounted, ref, watch } from 'vue'
import { fetchPatients } from '../api'
import type { Patient, PatientsState, PatientTableRow } from '../lib'

export const useSearchPatient = (cb: (search: string) => void) => {
    let timeout: Timeout

    const search = ref('')

    onBeforeUnmount(() => {
        clearTimeout(timeout)
    })

    watch(search, value => {
        clearTimeout(timeout)

        timeout = setTimeout(async () => {
            await cb(value)
        }, 300)
    })

    return search
}

export const useFetchPatients = async (
    search: string = '',
    page: Pagination['current_page'] = 1,
    state: PatientsState,
    converter: (list: Patient[]) => PatientTableRow[],
) => {
    const { data } = await fetchPatients({
        page,
        per_page: state.pagination.per_page,
        search,
    })

    const newData = converter(data.data)

    return {
        pagination: data,
        data: !state.data || search ? newData : [...state.data, ...newData],
    }
}

export const useBasePatientsLoad = (
    cb: (search?: string, page?: Pagination['current_page']) => Promise<void>,
    currentPage: Pagination['current_page'],
    lastPage: Pagination['last_page'],
    isFirstLoad: boolean,
) => {
    const loadData = async ($state: any) => {
        await cb('', currentPage + 1)
        if (currentPage < lastPage) {
            $state.loaded()
        } else {
            $state.complete()
        }
    }

    onMounted(async () => {
        if (isFirstLoad) await cb()
    })

    return loadData
}
