import type { LinkProps, UserBaseProps } from '@/shared'
import type { PatientRequestProps } from '../ui'

export type Patient = {
    id: number
    sex: string
    avatar: string
    name: string
    gender: Gender
    anamnesis: string | null
    asking: string | null
    birthdate: string
    children_count: number
    city: string
    contact: string
    email: string
    marital: string
    profession: string
    media: PatientMediaFile[]
    medical_test: PatientMedicalTest[]
    survey_attempts: PatientSurvey[]
    files: PatientFiles[]
    health_matrix: number[]
    appointments: Appointments[]
    event_reminder_customer: PatientReminder[]
}

export type PatientTableRow = {
    id: Patient['id']
    patient: UserBaseProps
    age: number
    gender: Gender
    contact?: LinkProps
    time?: string
    actions?: boolean
    type?: string
    description?: string
    request?: PatientRequestProps['request']
    applicationDate?: string
    reminder?: string
}

export type PatientsState = BaseStatePagination<Maybe<PatientTableRow[]>>

export enum PatientStep {
    MAIN,
    QUESTIONNAIRE,
    ANALYZES,
    FILES,
    HEALTH_MATRIX,
    PURPOSE,
}

export type PatientFiles = {
    id: number
    name: string
    file_name: string
    url: string
}

export type PatientSurvey = {
    id: number
    title: string
    survey_id: number
    attemp: number
    percent: number
    answers_count: number
    survey: {
        id: number
        title: string
        questions_count: number
        description: string
    }
}

export type PatientMediaFile = {
    id: number
    file_name: string
    created_at: string
}

export type PatientMedicalTest = {
    id: number
    title: string
    created_at: string
    unit: string | null
    medical_tests: any[]
}

export type Appointments = {
    id: number
    user_id: number
    complaint: string
    taking_medication: string
    taking_bud: string
    physical_activity: string
    stress: string
    sleep: string
    bad_habits: string
    conclusion: string
    created_at: string
    updated_at: string
    treatment_course_user?: PatientTreatmentCourse
    health_matrix: THealthMatrix
}

export type THealthMatrix = {
    id: number
    appointment_id: number
    antecedents: string | null
    triggers: string | null
    medmators: string | null
    nutrition: string | null
    sleep: string | null
    movement: string | null
    stress: string | null
    relation: string | null
    assimilation: string | null
    assimilation_color: string | null
    energy: string | null
    energy_color: string | null
    inflammation: string | null
    inflammation_color: string | null
    structure: string | null
    structure_color: string | null
    mental: string | null
    mental_color: string | null
    communications: string | null
    communications_color: string | null
    transport: string | null
    transport_color: string | null
    detoxification: string | null
    detoxification_color: string | null
    circle_mental: string | null
    circle_spiritual: string | null
    circle_emotional: string | null
    created_at: string
    updated_at: string
}

export type EditPatientData = {
    name?: string
    sex?: string
    city?: string
    asking?: string
    marital?: string
    contact?: string
    anamnesis?: string
    birthdate?: string
    profession?: string
    children_count?: string
}

export type EditAppointmentData = {
    complaint?: Appointments['complaint']
    taking_medication?: Appointments['taking_medication']
    taking_bud?: Appointments['taking_bud']
    physical_activity?: Appointments['physical_activity']
    stress?: Appointments['stress']
    sleep?: Appointments['sleep']
    bad_habits?: Appointments['bad_habits']
    conclusion?: Appointments['conclusion']
}

export type PatientReminder = {
    id: number
    text: string
    type: string
    user_id: number
    performer_id: number
    datetime: string
    created_at: string
    updated_at: string
}

export type PatientTreatmentCourse = {
    id: number
    title: string
    duration: number | null
    user_id: number
    performer_id: number
    created_at: string
    updated_at: string
    appointment_id: number
    nutrition: string | null
    medication: string
    buds: string | null
    analysis_and_research: string | null
    comment: string | null
    media: PatientFiles[]
    enabled: number
}

export type PatientAnalysis = {
    id?: number
    user_id: number
    performer_id?: number
    result: number | null
    marker_id: number
    quality: string
    date: string
    created_at?: string
    updated_at?: string
    state?: string
}
