import { defineStore } from 'pinia'
import { reactive } from 'vue'
import { patientsToMyPatients } from '@/entities/patient/model/converters'
import { Stores } from '@/shared'
import { deletePatient } from '../../api'
import type { Patient, PatientsState } from '../../lib'
import { useFetchPatients } from '../../lib'

export const usePatientsStore = defineStore(Stores.MY_PATIENTS, () => {
    const state = reactive<PatientsState>({
        loading: false,
        data: null,
        pagination: {
            current_page: 1,
            per_page: 10,
            last_page: 1,
        },
    })

    const setMyPatients = async (
        search: string = '',
        page: Pagination['current_page'] = 1,
    ) => {
        try {
            const { data, pagination } = await useFetchPatients(
                search,
                page,
                state,
                patientsToMyPatients,
            )

            state.pagination = pagination
            state.data = data
        } catch (e) {
            console.log(e)
        }
    }

    const deleteMyPatient = async (id: Patient['id']) => {
        try {
            await deletePatient(id)

            state.data = state.data?.filter(item => item.id !== id)
        } catch (e) {
            console.log(e)
        }
    }

    return {
        state,
        setMyPatients: setMyPatients,
        deleteMyPatient: deleteMyPatient,
    }
})
