import { defineStore } from 'pinia'
import { reactive } from 'vue'
import { Stores } from '@/shared'
import { type PatientsState, useFetchPatients } from '../../lib'
import { patientsToRequestsPatients } from '../converters'

export const useRequestPatientsStore = defineStore(
    Stores.REQUEST_PATIENTS,
    () => {
        const state = reactive<PatientsState>({
            loading: false,
            data: null,
            pagination: {
                current_page: 1,
                per_page: 10,
                last_page: 0,
            },
        })

        const setRequestPatients = async (
            search: string = '',
            page: Pagination['current_page'] = 1,
        ) => {
            try {
                const { data, pagination } = await useFetchPatients(
                    search,
                    page,
                    state,
                    patientsToRequestsPatients,
                )

                state.pagination = pagination
                state.data = data
            } catch (e) {
                console.log(e)
            }
        }

        return {
            state,
            setRequestPatients,
        }
    },
)
