import type { AxiosResponse } from 'axios'
import { fetchUser } from '@/entities'
import { type AuthData, baseApi, baseURL } from '@/shared'
import type { RegistrationData } from '../model'

export const tokenValidate = async () => {
    const { data } = await fetchUser()

    // @ts-ignore
    return data !== 1
}

export const login = (
    data: AuthAPI.POST.Login.Params,
): Promise<AuthAPI.POST.Login.Response> => baseApi.post('login', data)

export const loginYandex = (): Promise<YandexAPI.GET.loginYandex.Response> => baseURL.get('/login/yandex')

export const YandexCallBack = (token : String): Promise<YandexAPI.GET.YandexCallBack.Response> => baseURL.get(`/login/yandex/callback?access_token=${token}`)

export const registration = (
    data: AuthAPI.POST.Registration.Params,
): Promise<AuthAPI.POST.Registration.Response> => baseApi.post('register', data)

export const logout = (): Promise<AuthAPI.POST.Logout.Response> =>
    baseApi.post('logout')

export namespace AuthAPI {
    export namespace POST {
        export namespace Login {
            export type Params = AuthData
            export type Response = AxiosResponse<{
                data: {
                    access_token: string
                }
            }>
        }

        export namespace Registration {
            export type Params = RegistrationData
            export type Response = AxiosResponse<{
                data: {
                    access_token: string
                }
            }>
        }

        export namespace Logout {
            export type Response = AxiosResponse
        }
    }
}

export namespace YandexAPI {

    export namespace GET {
        export namespace YandexCallBack {
            export type Params = { token: string }
            export type Response = AxiosResponse<{
                data : {
                    access_token: string,
                    success: boolean,
                    token_type: string,
                    message: string | null
                }
            }>
        }
    }
    
    export namespace GET {
        export namespace loginYandex {
            export type Response = AxiosResponse<string>
        }
    }
}
