import { defineStore } from 'pinia'
import { computed, ref } from 'vue'
import { toast } from 'vue3-toastify'
import { calculation, fetchCalcUnits } from '@/features'
import type { CalculationData, CalculatorUnits } from '../lib'

export const useCalculatorStore = defineStore('calculator', () => {
    /**
     * ----------- State -------------
     */
    const units = ref<CalculatorUnits>({})
    const loading = ref<boolean>(false)

    /**
     * ----------- Actions -------------
     */
    const setUnits = async () => {
        loading.value = true
        try {
            const { data } = await fetchCalcUnits()
            if (data.data && Object.keys(data.data).length) {
                units.value = data.data
            }
        } catch (e: any) {
            console.log('e -> ', e)
        }
        loading.value = false
    }

    const calcValue = async (params: CalculationData) => {
        loading.value = true
        try {
            const { data } = await calculation(params)
            return data
        } catch (e: any) {
            toast.error(e?.error || '')
            console.log('e -> ', e)
        }
        loading.value = false
    }

    /**
     * ----------- Getters -------------
     */

    const formUnits = computed<{ key: string; title: string }[]>(() => {
        return Object.keys(units.value || {}).map(x => ({
            title: units.value?.[x]?.title || '',
            key: x,
        }))
    })

    return {
        formUnits,
        loading,
        setUnits,
        calcValue,
    }
})
