import { defineStore } from 'pinia'
import { reactive } from 'vue'
import type { ModalDialogProps } from '@/widgets/modals/ui/ModalDialog'
import { Stores } from '@/shared'

export enum ModalsName {
    DIALOG = 'dialog',
    EDITPATIENT = 'edit-patient',
    SELECTQUESTIONAIRE = 'select-questionnaire',
    ADDDESTINATION = 'add-destination',
    ADDREMINDER = 'add-reminder',
    VIEWQUESTIONNAIRE = 'view-questionnaire',
    ANALYSISHINTS = 'analysis-hint',
    VIEWOPTIMUMS = 'view-optimums',
}

type ModalsProps = ModalDialogProps

type ModalsStore = {
    active: Maybe<ModalsName>
    props: Maybe<ModalsProps>
}

export const useModalsStore = defineStore(Stores.MODALS, () => {
    const state = reactive<ModalsStore>({
        active: null,
        props: null,
    })

    const setModal = (
        modal: ModalsStore['active'],
        props?: ModalsStore['props'],
    ) => {
        state.active = modal
        state.props = props
    }

    const closeModal = () => {
        state.active = null
        state.props = null
    }

    return {
        state,
        setModal,
        closeModal,
    }
})
