import { declension, formattingDateForClient, getGender } from '@/shared'
import type { Columns } from './PatientTable.vue'

export const columnsData: Record<
    Columns,
    {
        name: string
        order: number
        width: number
        view?: {
            component?: {
                name: string
                propName?: string
                bind?: any
            }
            formatting?: any
        }
    }
> = {
    patient: {
        name: 'ФИО',
        order: 2,
        width: 270,
        view: {
            component: {
                name: 'user-base',
                bind: {
                    size: 'xs',
                },
            },
        },
    },
    age: {
        name: 'Возраст',
        order: 3,
        width: 100,
        view: {
            formatting: (age: number) =>
                declension(age, ['год', 'года', 'лет']),
        },
    },
    contact: {
        name: 'Контактные данные',
        order: 11,
        width: 190,
        view: {
            component: {
                name: 'link',
            },
        },
    },
    gender: {
        name: 'Пол',
        order: 4,
        width: 100,
        view: {
            formatting: getGender,
        },
    },
    time: {
        name: 'Время приема',
        order: 1,
        width: 100,
    },
    actions: {
        name: 'Действие',
        order: 11,
        width: 200,
    },
    type: {
        name: 'Тип',
        order: 1,
        width: 100,
    },
    applicationDate: {
        name: 'Дата заявки',
        order: 5,
        width: 125,
        view: {
            formatting: (date: string) => formattingDateForClient(date),
        },
    },
    description: {
        name: 'Описание',
        order: 1,
        width: 100,
    },
    request: {
        name: 'Запрос',
        order: 5,
        width: 160,
        view: {
            component: {
                name: 'patient-request',
                propName: 'request',
            },
        },
    },
    reminder: {
        name: 'Напоминание',
        order: 6,
        width: 120,
    },
}
